@@ -356,6 +356,7 @@ cd_util_show_sensor (CdSensor *sensor)
 	GList *list = NULL;
 	GMainLoop *loop = NULL;
 	GVariant *value_tmp;
+	GHashTable *metadata = NULL;
 
 	/* TRANSLATORS: the internal DBus path */
 	cd_util_print_field (_("Object Path"),
@@ -436,6 +437,19 @@ cd_util_show_sensor (CdSensor *sensor)
 		g_free (str_tmp);
 	}
 
+	/* list all the items of metadata */
+	metadata = cd_sensor_get_metadata (sensor);
+	list = g_hash_table_get_keys (metadata);
+	for (l = list; l != NULL; l = l->next) {
+		tmp = (const gchar *) g_hash_table_lookup (metadata,
+							   l->data);
+		str_tmp = g_strdup_printf ("%s=%s",
+					   (const gchar *) l->data, tmp);
+		/* TRANSLATORS: the metadata for the sensor */
+		cd_util_print_field (_("Metadata"), str_tmp);
+		g_free (str_tmp);
+	}
+
 	/* TRANSLATORS: if the sensor has a colord native driver */
 	cd_util_print_field (_("Native"),
 			     cd_sensor_get_native (sensor) ? "Yes" : "No");
@@ -479,6 +493,8 @@ cd_util_show_sensor (CdSensor *sensor)
 		goto out;
 	}
 out:
+	if (metadata != NULL)
+		g_hash_table_unref (metadata);
 	g_list_free (list);
 	if (options != NULL)
 		g_hash_table_unref (options);
@@ -518,7 +534,7 @@ cd_util_add (GPtrArray *array, const gchar *name, const gchar *description, CdUt
 
 	/* add each one */
 	names = g_strsplit (name, ",", -1);
-	for (i=0; names[i] != NULL; i++) {
+	for (i = 0; names[i] != NULL; i++) {
 		item = g_new0 (CdUtilItem, 1);
 		item->name = g_strdup (names[i]);
 		if (i == 0) {
@@ -631,7 +647,7 @@ cd_util_get_devices (CdUtilPrivate *priv, gchar **values, GError **error)
 		ret = FALSE;
 		goto out;
 	}
-	for (i=0; i < array->len; i++) {
+	for (i = 0; i < array->len; i++) {
 		device = g_ptr_array_index (array, i);
 		ret = cd_device_connect_sync (device, NULL, error);
 		if (!ret)
@@ -676,7 +692,7 @@ cd_util_get_devices_by_kind (CdUtilPrivate *priv, gchar **values, GError **error
 		ret = FALSE;
 		goto out;
 	}
-	for (i=0; i < array->len; i++) {
+	for (i = 0; i < array->len; i++) {
 		device = g_ptr_array_index (array, i);
 		ret = cd_device_connect_sync (device, NULL, error);
 		if (!ret)
@@ -708,7 +724,7 @@ cd_util_get_profiles (CdUtilPrivate *priv, gchar **values, GError **error)
 		ret = FALSE;
 		goto out;
 	}
-	for (i=0; i < array->len; i++) {
+	for (i = 0; i < array->len; i++) {
 		profile = g_ptr_array_index (array, i);
 		ret = cd_profile_connect_sync (profile, NULL, error);
 		if (!ret)
@@ -747,7 +763,7 @@ cd_util_get_sensors (CdUtilPrivate *priv, gchar **values, GError **error)
 				     _("There are no supported sensors attached"));
 		goto out;
 	}
-	for (i=0; i < array->len; i++) {
+	for (i = 0; i < array->len; i++) {
 		sensor = g_ptr_array_index (array, i);
 		ret = cd_sensor_connect_sync (sensor, NULL, error);
 		if (!ret)
@@ -787,7 +803,7 @@ cd_util_sensor_lock (CdUtilPrivate *priv, gchar **values, GError **error)
 				     _("There are no supported sensors attached"));
 		goto out;
 	}
-	for (i=0; i < array->len; i++) {
+	for (i = 0; i < array->len; i++) {
 		sensor = g_ptr_array_index (array, i);
 
 		ret = cd_sensor_connect_sync (sensor, NULL, error);
@@ -964,7 +980,7 @@ cd_util_sensor_set_options (CdUtilPrivate *priv, gchar **values, GError **error)
 	options = g_hash_table_new (g_str_hash, g_str_equal);
 	g_hash_table_insert (options, values[0], g_variant_new_string (values[1]));
 
-	for (i=0; i < array->len; i++) {
+	for (i = 0; i < array->len; i++) {
 		sensor = g_ptr_array_index (array, i);
 
 		ret = cd_sensor_connect_sync (sensor, NULL, error);
