@@ -1170,12 +1170,12 @@ colord_color_func (void)
 	g_assert (xyz != NULL);
 
 	/* nothing set */
-	cd_color_convert_xyz_to_yxy (xyz, &yxy);
+	cd_color_xyz_to_yxy (xyz, &yxy);
 	g_assert_cmpfloat (fabs (yxy.x - 0.0f), <, 0.001f);
 
 	/* set dummy values */
-	cd_color_set_xyz (xyz, 0.125, 0.25, 0.5);
-	cd_color_convert_xyz_to_yxy (xyz, &yxy);
+	cd_color_xyz_set (xyz, 0.125, 0.25, 0.5);
+	cd_color_xyz_to_yxy (xyz, &yxy);
 
 	g_assert_cmpfloat (fabs (yxy.x - 0.142857143f), <, 0.001f);
 	g_assert_cmpfloat (fabs (yxy.y - 0.285714286f), <, 0.001f);
@@ -1806,6 +1806,48 @@ colord_device_func (void)
 	g_object_unref (device);
 }
 
+static void
+colord_device_embedded_func (void)
+{
+	CdDevice *device;
+	gboolean ret;
+	GError *error = NULL;
+	GHashTable *device_props;
+	CdClient *client;
+
+	client = cd_client_new ();
+	ret = cd_client_connect_sync (client, NULL, &error);
+	g_assert_no_error (error);
+	g_assert (ret);
+
+	/* create device */
+	device_props = g_hash_table_new_full (g_str_hash, g_str_equal,
+					      g_free, g_free);
+	g_hash_table_insert (device_props,
+			     g_strdup (CD_DEVICE_PROPERTY_EMBEDDED),
+			     NULL);
+	device = cd_client_create_device_sync (client,
+					       "device_embedded",
+					       CD_OBJECT_SCOPE_TEMP,
+					       device_props,
+					       NULL,
+					       &error);
+	g_assert_no_error (error);
+	g_assert (device != NULL);
+
+	/* connect */
+	ret = cd_device_connect_sync (device, NULL, &error);
+	g_assert_no_error (error);
+	g_assert (ret);
+
+	/* check embedded */
+	g_assert (cd_device_get_embedded (device));
+
+	g_hash_table_unref (device_props);
+	g_object_unref (device);
+	g_object_unref (client);
+}
+
 static void
 colord_client_standard_space_func (void)
 {
@@ -2427,6 +2469,7 @@ main (int argc, char **argv)
 	g_test_add_func ("/colord/it8-ccmx", colord_it8_ccmx_func);
 	g_test_add_func ("/colord/device", colord_device_func);
 	g_test_add_func ("/colord/client", colord_client_func);
+	g_test_add_func ("/colord/device-embedded", colord_device_embedded_func);
 	g_test_add_func ("/colord/device-duplicate", colord_device_duplicate_func);
 	g_test_add_func ("/colord/device-seat", colord_device_seat_func);
 	g_test_add_func ("/colord/device-enabled", colord_device_enabled_func);
