@@ -100,6 +100,7 @@ struct _CdSensorPrivate
 	guint				 registration_id;
 	CdSensorIface			*desc;
 	GHashTable			*options;
+	GHashTable			*metadata;
 };
 
 enum {
@@ -907,6 +908,38 @@ out:
 	return value;
 }
 
+/**
+ * cd_sensor_get_metadata_as_variant:
+ **/
+static GVariant *
+cd_sensor_get_metadata_as_variant (CdSensor *sensor)
+{
+	GList *list, *l;
+	GVariantBuilder builder;
+	GVariant *value;
+
+	/* we always must have at least one bit of metadata */
+	if (g_hash_table_size (sensor->priv->metadata) == 0) {
+		value = g_variant_new_array (G_VARIANT_TYPE ("{sv}"),
+					     NULL, 0);
+		goto out;
+	}
+	/* add all the keys in the dictionary to the variant builder */
+	list = g_hash_table_get_keys (sensor->priv->metadata);
+	g_variant_builder_init (&builder, G_VARIANT_TYPE_ARRAY);
+	for (l = list; l != NULL; l = l->next) {
+		g_variant_builder_add (&builder,
+				       "{ss}",
+				       l->data,
+				       g_hash_table_lookup (sensor->priv->metadata,
+							    l->data));
+	}
+	g_list_free (list);
+	value = g_variant_builder_end (&builder);
+out:
+	return value;
+}
+
 /**
  * cd_sensor_get_nullable_for_string:
  **/
@@ -981,6 +1014,10 @@ cd_sensor_dbus_get_property (GDBusConnection *connection_, const gchar *sender,
 		retval = cd_sensor_get_options_as_variant (sensor);
 		goto out;
 	}
+	if (g_strcmp0 (property_name, CD_SENSOR_PROPERTY_METADATA) == 0) {
+		retval = cd_sensor_get_metadata_as_variant (sensor);
+		goto out;
+	}
 
 	g_critical ("failed to get property %s", property_name);
 out:
@@ -1051,13 +1088,16 @@ cd_sensor_set_from_device (CdSensor *sensor,
 			   GUdevDevice *device,
 			   GError **error)
 {
-	gboolean ret;
-	guint idx = 0;
-	const gchar *vendor_tmp = NULL;
-	const gchar *model_tmp = NULL;
-	const gchar *kind_str;
-	gboolean use_database;
 	CdSensorPrivate *priv = sensor->priv;
+	const gchar *images[] = { "attach", "calibrate", "screen", NULL };
+	const gchar *kind_str;
+	const gchar *model_tmp = NULL;
+	const gchar *vendor_tmp = NULL;
+	gboolean ret;
+	gboolean use_database;
+	gchar *tmp;
+	guint i;
+	guint idx = 0;
 
 	/* only use the database if we found both the VID and the PID */
 	use_database = g_udev_device_has_property (device, "ID_VENDOR_FROM_DATABASE") &&
@@ -1135,6 +1175,21 @@ cd_sensor_set_from_device (CdSensor *sensor,
 	if (ret)
 		priv->embedded = TRUE;
 
+	/* add image metadata if the files exist */
+	for (i = 0; images[i] != NULL; i++) {
+		tmp = g_strdup_printf ("%s/colord/icons/%s-%s.svg",
+				       DATADIR, kind_str, images[i]);
+		if (g_file_test (tmp, G_FILE_TEST_EXISTS)) {
+			g_debug ("helper image %s found", tmp);
+			g_hash_table_insert (priv->metadata,
+					     g_strdup (CD_SENSOR_METADATA_IMAGE_ATTACH),
+					     tmp);
+		} else {
+			g_debug ("helper image %s not found", tmp);
+			g_free (tmp);
+		}
+	}
+
 	/* no caps */
 	if (idx == 0) {
 		ret = FALSE;
@@ -1361,6 +1416,10 @@ cd_sensor_init (CdSensor *sensor)
 						       g_str_equal,
 						       (GDestroyNotify) g_free,
 						       (GDestroyNotify) g_variant_unref);
+	sensor->priv->metadata = g_hash_table_new_full (g_str_hash,
+							g_str_equal,
+							g_free,
+							g_free);
 }
 
 /**
@@ -1389,6 +1448,7 @@ cd_sensor_finalize (GObject *object)
 	g_free (priv->device_path);
 	g_free (priv->object_path);
 	g_hash_table_unref (priv->options);
+	g_hash_table_unref (priv->metadata);
 
 	G_OBJECT_CLASS (cd_sensor_parent_class)->finalize (object);
 }
